==> tdstone-0.1.0-py3-none-any.whl: tdstone/prepared_dataset.py <==
import teradataml as tdml

def preparedataset_from_teradata_dataframe(dataset,ID_Columns,Partition,FoldID):
    # - dataset is a teradataml dataframe.
    # - ID_Columns is the list of columns that is unique per partition
    # - Partition is the list of columns defining a partition
    # - FoldID define what is train or test data or multiple folds
    # This function add three columns to the dataset:
    # - STO_ID
    # - STO_PARTITION_ID (a JSON)
    # - STO_FOLD_ID

    cols = [str.lower(x) for x in dataset.columns]
    for c in ['STO_ID','STO_PARTITION_ID','STO_FOLD_ID']:
        if c in cols:
            print(f'{c} already exists in your dataset. Please rename or remove this column.')
            return

    new_cols = {
        'STO_ROW_ID'       : tdml.sqlalchemy.literal_column(f"CAST(JSON_COMPOSE({','.join(ID_Columns)}) AS VARCHAR(2000) CHARACTER SET UNICODE)"),
        'STO_PARTITION_ID' : tdml.sqlalchemy.literal_column(f"CAST(JSON_COMPOSE({','.join(Partition)}) AS VARCHAR(2000) CHARACTER SET UNICODE)"),
        'STO_FOLD_ID'      : FoldID

    }

    dataset_training = dataset.assign(**new_cols)


    return dataset_training


def preparedataset_from_table(schema, view_name, input_table_name, input_schema_name, ID_Columns,Partition,FoldID):
    # - schema is the schema of the output view.
    # - view_name is the name of the output view
    # - input_table_name is the complete name schema.table_name of the dataset
    # - ID_Columns is the list of columns that is unique per partition
    # - Partition is the list of columns defining a partition
    # - FoldID define what is train or test data or multiple folds
    # This function add three columns to the dataset:
    # - STO_ID
    # - STO_PARTITION_ID (a JSON)
    # - STO_FOLD_ID

    columns = tdml.DataFrame(tdml.in_schema(input_schema_name,input_table_name)).columns
    {','.join([x for x in columns if x.lower() != FoldID.lower()])}
    query = f"""
        REPLACE VIEW {schema}.{view_name} AS
        SEL
            A.*
        ,   CAST(JSON_COMPOSE({','.join(ID_Columns)}) AS VARCHAR(2000) CHARACTER SET UNICODE) AS STO_ROW_ID
        ,   CAST(JSON_COMPOSE({','.join(Partition)}) AS VARCHAR(2000) CHARACTER SET UNICODE) AS STO_PARTITION_ID
        ,   {FoldID} AS STO_FOLD_ID
        FROM {input_schema_name}.{input_table_name} A
    """

    tdml.get_context().execute(query)

    return tdml.DataFrame(tdml.in_schema(schema,view_name))

==> tdstone-0.1.1-py3-none-any.whl: tdstone/prepared_dataset.py <==
import teradataml as tdml

def preparedataset_from_teradata_dataframe(dataset,ID_Columns,Partition,FoldID):
    # - dataset is a teradataml dataframe.
    # - ID_Columns is the list of columns that is unique per partition
    # - Partition is the list of columns defining a partition
    # - FoldID define what is train or test data or multiple folds
    # This function add three columns to the dataset:
    # - STO_ID
    # - STO_PARTITION_ID (a JSON)
    # - STO_FOLD_ID

    cols = [str.lower(x) for x in dataset.columns]
    for c in ['STO_ID','STO_PARTITION_ID','STO_FOLD_ID']:
        if c in cols:
            print(f'{c} already exists in your dataset. Please rename or remove this column.')
            return

    new_cols = {
        'STO_ROW_ID'       : tdml.sqlalchemy.literal_column(f"CAST(JSON_COMPOSE({','.join(Partition+ID_Columns)}) AS VARCHAR(2000) CHARACTER SET UNICODE)"),
        'STO_PARTITION_ID' : tdml.sqlalchemy.literal_column(f"CAST(JSON_COMPOSE({','.join(Partition)}) AS VARCHAR(2000) CHARACTER SET UNICODE)"),
        'STO_FOLD_ID'      : FoldID

    }

    dataset_training = dataset.assign(**new_cols)


    return dataset_training


def preparedataset_from_table(schema, view_name, input_table_name, input_schema_name, ID_Columns,Partition,FoldID):
    # - schema is the schema of the output view.
    # - view_name is the name of the output view
    # - input_table_name is the complete name schema.table_name of the dataset
    # - ID_Columns is the list of columns that is unique per partition
    # - Partition is the list of columns defining a partition
    # - FoldID define what is train or test data or multiple folds
    # This function add three columns to the dataset:
    # - STO_ID
    # - STO_PARTITION_ID (a JSON)
    # - STO_FOLD_ID



    columns = tdml.DataFrame(tdml.in_schema(input_schema_name,input_table_name)).columns
    {','.join([x for x in columns if x.lower() != FoldID.lower()])}
    query = f"""
        REPLACE VIEW {schema}.{view_name} AS
        SEL
            A.*
        ,   CAST(JSON_COMPOSE({','.join(Partition+ID_Columns)}) AS VARCHAR(2000) CHARACTER SET UNICODE) AS STO_ROW_ID
        ,   CAST(JSON_COMPOSE({','.join(Partition)}) AS VARCHAR(2000) CHARACTER SET UNICODE) AS STO_PARTITION_ID
        ,   {FoldID} AS STO_FOLD_ID
        FROM {input_schema_name}.{input_table_name} A
    """

    tdml.get_context().execute(query)

    return tdml.DataFrame(tdml.in_schema(schema,view_name))
